import logging
from telegram import Update
from telegram.ext import ContextTypes
from .base import InfoCommandsBase

logger = logging.getLogger(__name__)

class CommandsInfo(InfoCommandsBase):
    """Handles the commands information command."""

    async def commands_command(self, update: Update, context: ContextTypes.DEFAULT_TYPE) -> None:
        """Handle the /commands command to show available commands."""
        if not self._is_authorized(update):
            return

        try:
            commands_text = ["🤖 <b>Available Commands</b>"]

            # Trading Commands
            commands_text.append("\n📈 <b>Trading Commands:</b>")
            commands_text.append("• /long [token] [amount] - Open a long position")
            commands_text.append("• /short [token] [amount] - Open a short position")
            commands_text.append("• /exit [token] - Close position")
            commands_text.append("• /sl [token] [price] - Set stop loss")
            commands_text.append("• /tp [token] [price] - Set take profit")
            commands_text.append("• /coo [token] [price] - Cancel open orders")

            # Information Commands
            commands_text.append("\n📊 <b>Information Commands:</b>")
            commands_text.append("• /balance - Show account balance")
            commands_text.append("• /positions - Show open positions")
            commands_text.append("• /orders - Show open orders")
            commands_text.append("• /trades - Show recent trades")
            commands_text.append("• /stats - Show trading statistics")
            commands_text.append("• /market - Show market overview")
            commands_text.append("• /price [token] - Show token price")
            commands_text.append("• /performance [token] - Show performance stats")
            commands_text.append("• /daily - Show daily performance")
            commands_text.append("• /weekly - Show weekly performance")
            commands_text.append("• /monthly - Show monthly performance")
            commands_text.append("• /risk - Show risk management info")
            commands_text.append("• /balance_adjustments - Show balance adjustments")

            # Management Commands
            commands_text.append("\n⚙️ <b>Management Commands:</b>")
            commands_text.append("• /monitoring - Show monitoring status")
            commands_text.append("• /alarm - Set price alarms")
            commands_text.append("• /logs - Show recent logs")
            commands_text.append("• /debug - Show debug information")
            commands_text.append("• /version - Show bot version")
            commands_text.append("• /keyboard - Toggle keyboard")

            # Help
            commands_text.append("\n💡 <b>Help:</b>")
            commands_text.append("• Use /help for detailed command information")
            commands_text.append("• Add ? after any command for help with that command")

            await self._reply(update, "\n".join(commands_text))

        except Exception as e:
            error_message = f"❌ Error processing commands command: {str(e)}"
            await self._reply(update, error_message)
            logger.error(f"Error in commands command: {e}") 